# ravest
> _(archaic) second-person singular simple present indicative of rave_

**Radial Velocity fitting, simulation and mass precision estimation**
- Simulate RV data for given orbital and instrumental parameters
- Fit RV data with MCMC to explore posterior distributions for parameters
- Estimate the precision on mass estimate $M_p\sin{i}$: what precision can you expect from N observations, or how many observations are required to reach a target precision?


## Installation

```bash
$ pip install ravest
```

## Usage

See the [example notebook](https://ravest.readthedocs.io/en/latest/Examples/example_model.html) for `ravest.model`.

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`ravest` was created by Ross Dobson. It is licensed under the terms of the MIT license.
